@@ -223,10 +223,10 @@ rb_song_info_init (RBSongInfo *song_info)
 	/* create the dialog and some buttons backward - forward - close */
 	song_info->priv = g_new0 (RBSongInfoPrivate, 1);
 
-	g_signal_connect (G_OBJECT (song_info),
-			  "response",
-			  G_CALLBACK (rb_song_info_response_cb),
-			  song_info);
+	g_signal_connect_object (G_OBJECT (song_info),
+				 "response",
+				 G_CALLBACK (rb_song_info_response_cb),
+				 song_info, 0);
 
 	gtk_dialog_set_has_separator (GTK_DIALOG (song_info), FALSE);
 
@@ -250,19 +250,19 @@ rb_song_info_construct_single (RBSongInfo *song_info, GladeXML *xml,
 							   GTK_STOCK_GO_BACK,
 							   GTK_RESPONSE_NONE);
 	
-	g_signal_connect (G_OBJECT (song_info->priv->backward),
-			  "clicked",
-			  G_CALLBACK (rb_song_info_backward_clicked_cb),
-			  song_info);
+	g_signal_connect_object (G_OBJECT (song_info->priv->backward),
+				 "clicked",
+				 G_CALLBACK (rb_song_info_backward_clicked_cb),
+				 song_info, 0);
 	
 	song_info->priv->forward = gtk_dialog_add_button (GTK_DIALOG (song_info),
 							   GTK_STOCK_GO_FORWARD,
 							   GTK_RESPONSE_NONE);
 	
-	g_signal_connect (G_OBJECT (song_info->priv->forward),
-			  "clicked",
-			  G_CALLBACK (rb_song_info_forward_clicked_cb),
-			  song_info);
+	g_signal_connect_object (G_OBJECT (song_info->priv->forward),
+				 "clicked",
+				 G_CALLBACK (rb_song_info_forward_clicked_cb),
+				 song_info, 0);
 
 	gtk_window_set_title (GTK_WINDOW (song_info), _("Song Properties"));
 
@@ -334,14 +334,14 @@ rb_song_info_construct_single (RBSongInfo *song_info, GladeXML *xml,
 	}
 
 	/* whenever you press a mnemonic, the associated GtkEntry's text gets highlighted */
-	g_signal_connect (G_OBJECT (song_info->priv->title),
-			  "mnemonic-activate",
-			  G_CALLBACK (rb_song_info_mnemonic_cb),
-			  NULL);
-	g_signal_connect (G_OBJECT (song_info->priv->track_cur),
-			  "mnemonic-activate",
-			  G_CALLBACK (rb_song_info_mnemonic_cb),
-			  NULL);
+	g_signal_connect_object (G_OBJECT (song_info->priv->title),
+				 "mnemonic-activate",
+				 G_CALLBACK (rb_song_info_mnemonic_cb),
+				 NULL, 0);
+	g_signal_connect_object (G_OBJECT (song_info->priv->track_cur),
+				 "mnemonic-activate",
+				 G_CALLBACK (rb_song_info_mnemonic_cb),
+				 NULL, 0);
 
 	gtk_editable_set_editable (GTK_EDITABLE (song_info->priv->title), editable);
 	gtk_editable_set_editable  (GTK_EDITABLE (song_info->priv->track_cur), editable);
@@ -464,26 +464,26 @@ rb_song_info_constructor (GType type, guint n_construct_properties,
 		g_free (str_final);
 	}
 
-	g_signal_connect (G_OBJECT (song_info->priv->artist),
-			  "mnemonic-activate",
-			  G_CALLBACK (rb_song_info_mnemonic_cb),
-			  NULL);
-	g_signal_connect (G_OBJECT (song_info->priv->album),
-			  "mnemonic-activate",
-			  G_CALLBACK (rb_song_info_mnemonic_cb),
-			  NULL);
-	g_signal_connect (G_OBJECT (song_info->priv->genre),
-			  "mnemonic-activate",
-			  G_CALLBACK (rb_song_info_mnemonic_cb),
-			  NULL);
+	g_signal_connect_object (G_OBJECT (song_info->priv->artist),
+				 "mnemonic-activate",
+				 G_CALLBACK (rb_song_info_mnemonic_cb),
+				 NULL, 0);
+	g_signal_connect_object (G_OBJECT (song_info->priv->album),
+				 "mnemonic-activate",
+				 G_CALLBACK (rb_song_info_mnemonic_cb),
+				 NULL, 0);
+	g_signal_connect_object (G_OBJECT (song_info->priv->genre),
+				 "mnemonic-activate",
+				 G_CALLBACK (rb_song_info_mnemonic_cb),
+				 NULL, 0);
 
 	song_info->priv->auto_rate_notify_id
 		= eel_gconf_notification_add (CONF_AUTO_RATE,
 					      (GConfClientNotifyFunc) rb_song_info_auto_rate_conf_changed_cb,
 					      song_info);
-	g_signal_connect (song_info->priv->auto_rate, "toggled",
-			  G_CALLBACK (rb_song_info_auto_rate_toggled_cb),
-			  song_info);
+	g_signal_connect_object (song_info->priv->auto_rate, "toggled",
+				 G_CALLBACK (rb_song_info_auto_rate_toggled_cb),
+				 song_info, 0);
 
 	/* this widget has to be customly created */
 	song_info->priv->rating = GTK_WIDGET (rb_rating_new ());
@@ -689,8 +689,7 @@ rb_song_info_set_entry_rating (RBSongInfo *info,
 			    RHYTHMDB_PROP_AUTO_RATE,
 			    &value);
 	g_value_unset (&value);
-
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (info->priv->auto_rate), FALSE);
+	
 }
 	
 
@@ -712,6 +711,8 @@ rb_song_info_rated_cb (RBRating *rating,
 	g_object_set (G_OBJECT (song_info->priv->rating),
 		      "score", score,
 		      NULL);
+
+	rb_song_info_update_auto_rate (song_info);
 }
 
 static void
@@ -955,7 +956,7 @@ rb_song_info_update_last_played (RBSongInfo *song_info)
 }
 
 static void
-rb_song_info_update_auto_rate (RBSongInfo *song_info)
+rb_song_info_update_auto_rate_single (RBSongInfo *song_info)
 {
 	gboolean auto_rate;
 	gboolean global_auto_rate;
@@ -981,6 +982,59 @@ rb_song_info_update_auto_rate (RBSongInfo *song_info)
 	gtk_widget_set_sensitive (song_info->priv->auto_rate, global_auto_rate);
 }
 
+static void
+rb_song_info_update_auto_rate_multiple (RBSongInfo *song_info)
+{
+	gboolean first_auto_rate;
+	gboolean global_auto_rate;
+	gboolean inconsistent = FALSE;
+	GList *tem;
+	
+	g_return_if_fail (RB_IS_SONG_INFO (song_info));
+
+	first_auto_rate = rhythmdb_entry_get_boolean (song_info->priv->db,
+						      song_info->priv->selected_entries->data,
+						      RHYTHMDB_PROP_AUTO_RATE);
+	for (tem = song_info->priv->selected_entries; tem; tem = tem->next) {
+		gboolean auto_rate
+			= rhythmdb_entry_get_boolean (song_info->priv->db,
+						      tem->data,
+						      RHYTHMDB_PROP_AUTO_RATE);
+		if (auto_rate != first_auto_rate) {
+			inconsistent = TRUE;
+			break;
+		}
+	}
+
+	gtk_toggle_button_set_inconsistent (GTK_TOGGLE_BUTTON (song_info->priv->auto_rate),
+					    inconsistent);
+					    
+	if (!inconsistent) {
+		/* We have to block our signal handlers from thinking this
+		   is a user-originated setting */
+		g_signal_handlers_block_by_func (song_info->priv->auto_rate,
+						 rb_song_info_auto_rate_toggled_cb, song_info);
+		g_object_set (G_OBJECT (song_info->priv->auto_rate),
+			      "active", first_auto_rate,
+			      NULL);
+		g_signal_handlers_unblock_by_func (song_info->priv->auto_rate,
+						   rb_song_info_auto_rate_toggled_cb, song_info);
+	}
+	
+	global_auto_rate = eel_gconf_get_boolean (CONF_AUTO_RATE);
+	gtk_widget_set_sensitive (song_info->priv->auto_rate_label, global_auto_rate);
+	gtk_widget_set_sensitive (song_info->priv->auto_rate, global_auto_rate);
+}
+
+static void
+rb_song_info_update_auto_rate (RBSongInfo *song_info)
+{
+	if (song_info->priv->current_entry)
+		rb_song_info_update_auto_rate_single (song_info);
+	else
+		rb_song_info_update_auto_rate_multiple (song_info);
+}
+
 static void
 rb_song_info_update_rating (RBSongInfo *song_info)
 {
